"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AnimatedAutocomplete = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeGestureHandler = require("react-native-gesture-handler");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

var _AnimatedModal = require("./AnimatedModal");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const AnimatedAutocomplete = ({
  mainInputViewStyle,
  mainInputTextStyle,
  data,
  closeIcon,
  searchIcon,
  value,
  onSelectItem
}) => {
  const {
    height
  } = _reactNative.Dimensions.get('window');

  const modalHeight = new _reactNativeReanimated.Value(0);
  const modalTranslateY = new _reactNativeReanimated.Value(height);
  const mainTextOpacity = new _reactNativeReanimated.Value(1);
  const searchBarRef = /*#__PURE__*/(0, _react.createRef)();

  const handleTapStateChange = event => {
    if (event.nativeEvent.state === _reactNativeGestureHandler.State.BEGAN) {
      _reactNativeReanimated.default.timing(mainTextOpacity, {
        toValue: 0.2,
        duration: 50,
        easing: _reactNativeReanimated.Easing.ease
      }).start();
    } else {
      _reactNativeReanimated.default.timing(mainTextOpacity, {
        toValue: 1,
        duration: 50,
        easing: _reactNativeReanimated.Easing.ease
      }).start();
    }

    _reactNativeReanimated.default.timing(modalTranslateY, {
      toValue: 0,
      duration: 300,
      easing: _reactNativeReanimated.Easing.sin
    }).start(() => searchBarRef.current && searchBarRef.current.focus());

    _reactNativeReanimated.default.timing(modalHeight, {
      toValue: height,
      duration: 300,
      easing: _reactNativeReanimated.Easing.sin
    }).start();
  };

  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.mainViewStyle
  }, /*#__PURE__*/_react.default.createElement(_reactNativeGestureHandler.TapGestureHandler, {
    onHandlerStateChange: handleTapStateChange,
    numberOfTaps: 1
  }, /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.animatedViewStyle, mainInputViewStyle, {
      opacity: mainTextOpacity
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
    style: [styles.mainText, mainInputTextStyle]
  }, value))), /*#__PURE__*/_react.default.createElement(_AnimatedModal.AnimatedModal, {
    animatedHeight: modalHeight,
    translateY: modalTranslateY,
    datalist: data,
    autocompleteText: value,
    setAutocompleteText: onSelectItem,
    closeIcon: closeIcon,
    searchIcon: searchIcon,
    searchRef: searchBarRef
  }));
};

exports.AnimatedAutocomplete = AnimatedAutocomplete;

const styles = _reactNative.StyleSheet.create({
  flexOne: {
    flex: 1
  },
  mainText: {
    fontSize: 25
  },
  animatedViewStyle: {
    flexDirection: 'row',
    borderRadius: 10,
    shadowOffset: {
      width: 2,
      height: 2
    },
    shadowColor: 'black',
    shadowRadius: 5,
    shadowOpacity: 0.5,
    backgroundColor: 'white',
    padding: 10,
    width: 200,
    height: 50
  },
  mainViewStyle: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=AnimatedAutocomplete.js.map