"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AnimatedModal = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _reactNativeReanimated = _interopRequireWildcard(require("react-native-reanimated"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const {
  width,
  height
} = _reactNative.Dimensions.get('window');

const AnimatedModal = ({
  translateY,
  animatedHeight,
  datalist,
  autocompleteText,
  setAutocompleteText,
  closeIcon,
  searchIcon,
  searchRef
}) => {
  const listMaxHeight = new _reactNativeReanimated.Value(height * 0.8);

  const closeModal = item => {
    _reactNativeReanimated.default.timing(translateY, {
      toValue: height,
      duration: 300,
      easing: _reactNativeReanimated.Easing.ease
    }).start(() => {
      item && setAutocompleteText(item);
      setSearchBarText('');
      setFilterData(originalData);

      _reactNative.Keyboard.dismiss();
    });

    _reactNativeReanimated.default.timing(animatedHeight, {
      toValue: 0,
      duration: 500,
      easing: _reactNativeReanimated.Easing.ease
    }).start();
  };

  (0, _react.useEffect)(() => {
    _reactNative.Keyboard.addListener('keyboardDidShow', _keyboardDidShow);

    _reactNative.Keyboard.addListener('keyboardDidHide', _keyboardDidHide); // cleanup function


    return () => {
      _reactNative.Keyboard.removeListener('keyboardDidShow', _keyboardDidShow);

      _reactNative.Keyboard.removeListener('keyboardDidHide', _keyboardDidHide);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const _keyboardDidShow = () => {
    _reactNativeReanimated.default.timing(listMaxHeight, {
      toValue: height * 0.5,
      duration: 500,
      easing: _reactNativeReanimated.Easing.ease
    }).start();
  };

  const _keyboardDidHide = () => {
    _reactNativeReanimated.default.timing(listMaxHeight, {
      toValue: height * 0.8,
      duration: 300,
      easing: _reactNativeReanimated.Easing.ease
    }).start();
  };

  const renderItem = ({
    item
  }) => {
    return /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
      style: styles.touchableOpacity,
      onPress: () => closeModal(item)
    }, /*#__PURE__*/_react.default.createElement(_reactNative.Text, {
      style: styles.renderText
    }, item));
  };

  const [originalData] = (0, _react.useState)(datalist);
  const [filterData, setFilterData] = (0, _react.useState)(datalist);
  const [searchBarText, setSearchBarText] = (0, _react.useState)(autocompleteText);

  const handleChangeSearchBarText = text => {
    setSearchBarText(text);
    text.length ? setFilterData(originalData.filter(item => item.includes(text))) : setFilterData(originalData);
  };

  return /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: { ...styles.animatedModal,
      height: animatedHeight,
      transform: [{
        translateY: translateY
      }]
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.mainContent
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.searchBar
  }, searchIcon !== null && searchIcon !== void 0 ? searchIcon : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: require('./assets/search-outline.jpg'),
    style: styles.searchIcon
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    style: styles.textInput,
    value: searchBarText,
    onChangeText: handleChangeSearchBarText,
    autoCorrect: false,
    ref: searchRef
  }), /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    onPress: () => closeModal()
  }, closeIcon !== null && closeIcon !== void 0 ? closeIcon : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: require('./assets/close-outline.jpg'),
    style: styles.closeIcon
  }))), /*#__PURE__*/_react.default.createElement(_reactNativeReanimated.default.View, {
    style: [styles.animatedView, {
      height: listMaxHeight
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, {
    data: filterData,
    renderItem: renderItem,
    keyExtractor: item => item,
    keyboardShouldPersistTaps: 'always'
  }))));
};

exports.AnimatedModal = AnimatedModal;

const styles = _reactNative.StyleSheet.create({
  searchBar: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-around',
    borderRadius: 10,
    shadowOffset: {
      width: 2,
      height: 2
    },
    shadowColor: 'black',
    shadowRadius: 5,
    shadowOpacity: 0.5,
    backgroundColor: 'white',
    padding: 10
  },
  searchIcon: {
    height: 30,
    width: 30
  },
  closeIcon: {
    height: 30,
    width: 30
  },
  renderText: {
    fontSize: 18,
    color: 'grey'
  },
  animatedView: {
    overflow: 'hidden',
    paddingVertical: 5
  },
  iconStyle: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 0
  },
  mainContent: {
    width: '100%',
    height: '100%',
    padding: 10
  },
  textInput: {
    width: '80%',
    height: '100%',
    backgroundColor: 'white',
    borderColor: 'white',
    borderWidth: 1,
    fontSize: 25,
    padding: 0
  },
  touchableOpacity: {
    width: '100%',
    backgroundColor: '#f2f2f2',
    borderBottomColor: 'grey',
    borderBottomWidth: 1,
    padding: 15
  },
  animatedModal: {
    position: 'absolute',
    top: 0,
    height: height,
    width: width,
    marginHorizontal: 'auto',
    display: 'flex',
    borderRadius: 25,
    paddingVertical: 50,
    justifyContent: 'flex-start',
    backgroundColor: 'white',
    alignItems: 'center'
  }
});
//# sourceMappingURL=AnimatedModal.js.map