import React, { createRef } from 'react';
import { Dimensions, StyleSheet, Text, View } from 'react-native';
import { State, TapGestureHandler } from 'react-native-gesture-handler';
import Animated, { Easing, Value } from 'react-native-reanimated';
import { AnimatedModal } from './AnimatedModal';
export const AnimatedAutocomplete = ({
  mainInputViewStyle,
  mainInputTextStyle,
  data,
  closeIcon,
  searchIcon,
  value,
  onSelectItem
}) => {
  const {
    height
  } = Dimensions.get('window');
  const modalHeight = new Value(0);
  const modalTranslateY = new Value(height);
  const mainTextOpacity = new Value(1);
  const searchBarRef = /*#__PURE__*/createRef();

  const handleTapStateChange = event => {
    if (event.nativeEvent.state === State.BEGAN) {
      Animated.timing(mainTextOpacity, {
        toValue: 0.2,
        duration: 50,
        easing: Easing.ease
      }).start();
    } else {
      Animated.timing(mainTextOpacity, {
        toValue: 1,
        duration: 50,
        easing: Easing.ease
      }).start();
    }

    Animated.timing(modalTranslateY, {
      toValue: 0,
      duration: 300,
      easing: Easing.sin
    }).start(() => searchBarRef.current && searchBarRef.current.focus());
    Animated.timing(modalHeight, {
      toValue: height,
      duration: 300,
      easing: Easing.sin
    }).start();
  };

  return /*#__PURE__*/React.createElement(View, {
    style: styles.mainViewStyle
  }, /*#__PURE__*/React.createElement(TapGestureHandler, {
    onHandlerStateChange: handleTapStateChange,
    numberOfTaps: 1
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.animatedViewStyle, mainInputViewStyle, {
      opacity: mainTextOpacity
    }]
  }, /*#__PURE__*/React.createElement(Text, {
    style: [styles.mainText, mainInputTextStyle]
  }, value))), /*#__PURE__*/React.createElement(AnimatedModal, {
    animatedHeight: modalHeight,
    translateY: modalTranslateY,
    datalist: data,
    autocompleteText: value,
    setAutocompleteText: onSelectItem,
    closeIcon: closeIcon,
    searchIcon: searchIcon,
    searchRef: searchBarRef
  }));
};
const styles = StyleSheet.create({
  flexOne: {
    flex: 1
  },
  mainText: {
    fontSize: 25
  },
  animatedViewStyle: {
    flexDirection: 'row',
    borderRadius: 10,
    shadowOffset: {
      width: 2,
      height: 2
    },
    shadowColor: 'black',
    shadowRadius: 5,
    shadowOpacity: 0.5,
    backgroundColor: 'white',
    padding: 10,
    width: 200,
    height: 50
  },
  mainViewStyle: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=AnimatedAutocomplete.js.map