import React, { useEffect, useState } from 'react';
import { Dimensions, FlatList, Image, Keyboard, StyleSheet, Text, TextInput, TouchableOpacity, View } from 'react-native';
import Animated, { Easing, Value } from 'react-native-reanimated';
const {
  width,
  height
} = Dimensions.get('window');
export const AnimatedModal = ({
  translateY,
  animatedHeight,
  datalist,
  autocompleteText,
  setAutocompleteText,
  closeIcon,
  searchIcon,
  searchRef
}) => {
  const listMaxHeight = new Value(height * 0.8);

  const closeModal = item => {
    Animated.timing(translateY, {
      toValue: height,
      duration: 300,
      easing: Easing.ease
    }).start(() => {
      item && setAutocompleteText(item);
      setSearchBarText('');
      setFilterData(originalData);
      Keyboard.dismiss();
    });
    Animated.timing(animatedHeight, {
      toValue: 0,
      duration: 500,
      easing: Easing.ease
    }).start();
  };

  useEffect(() => {
    Keyboard.addListener('keyboardDidShow', _keyboardDidShow);
    Keyboard.addListener('keyboardDidHide', _keyboardDidHide); // cleanup function

    return () => {
      Keyboard.removeListener('keyboardDidShow', _keyboardDidShow);
      Keyboard.removeListener('keyboardDidHide', _keyboardDidHide);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const _keyboardDidShow = () => {
    Animated.timing(listMaxHeight, {
      toValue: height * 0.5,
      duration: 500,
      easing: Easing.ease
    }).start();
  };

  const _keyboardDidHide = () => {
    Animated.timing(listMaxHeight, {
      toValue: height * 0.8,
      duration: 300,
      easing: Easing.ease
    }).start();
  };

  const renderItem = ({
    item
  }) => {
    return /*#__PURE__*/React.createElement(TouchableOpacity, {
      style: styles.touchableOpacity,
      onPress: () => closeModal(item)
    }, /*#__PURE__*/React.createElement(Text, {
      style: styles.renderText
    }, item));
  };

  const [originalData] = useState(datalist);
  const [filterData, setFilterData] = useState(datalist);
  const [searchBarText, setSearchBarText] = useState(autocompleteText);

  const handleChangeSearchBarText = text => {
    setSearchBarText(text);
    text.length ? setFilterData(originalData.filter(item => item.includes(text))) : setFilterData(originalData);
  };

  return /*#__PURE__*/React.createElement(Animated.View, {
    style: { ...styles.animatedModal,
      height: animatedHeight,
      transform: [{
        translateY: translateY
      }]
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.mainContent
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.searchBar
  }, searchIcon !== null && searchIcon !== void 0 ? searchIcon : /*#__PURE__*/React.createElement(Image, {
    source: require('./assets/search-outline.jpg'),
    style: styles.searchIcon
  }), /*#__PURE__*/React.createElement(TextInput, {
    style: styles.textInput,
    value: searchBarText,
    onChangeText: handleChangeSearchBarText,
    autoCorrect: false,
    ref: searchRef
  }), /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: () => closeModal()
  }, closeIcon !== null && closeIcon !== void 0 ? closeIcon : /*#__PURE__*/React.createElement(Image, {
    source: require('./assets/close-outline.jpg'),
    style: styles.closeIcon
  }))), /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.animatedView, {
      height: listMaxHeight
    }]
  }, /*#__PURE__*/React.createElement(FlatList, {
    data: filterData,
    renderItem: renderItem,
    keyExtractor: item => item,
    keyboardShouldPersistTaps: 'always'
  }))));
};
const styles = StyleSheet.create({
  searchBar: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-around',
    borderRadius: 10,
    shadowOffset: {
      width: 2,
      height: 2
    },
    shadowColor: 'black',
    shadowRadius: 5,
    shadowOpacity: 0.5,
    backgroundColor: 'white',
    padding: 10
  },
  searchIcon: {
    height: 30,
    width: 30
  },
  closeIcon: {
    height: 30,
    width: 30
  },
  renderText: {
    fontSize: 18,
    color: 'grey'
  },
  animatedView: {
    overflow: 'hidden',
    paddingVertical: 5
  },
  iconStyle: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    padding: 0
  },
  mainContent: {
    width: '100%',
    height: '100%',
    padding: 10
  },
  textInput: {
    width: '80%',
    height: '100%',
    backgroundColor: 'white',
    borderColor: 'white',
    borderWidth: 1,
    fontSize: 25,
    padding: 0
  },
  touchableOpacity: {
    width: '100%',
    backgroundColor: '#f2f2f2',
    borderBottomColor: 'grey',
    borderBottomWidth: 1,
    padding: 15
  },
  animatedModal: {
    position: 'absolute',
    top: 0,
    height: height,
    width: width,
    marginHorizontal: 'auto',
    display: 'flex',
    borderRadius: 25,
    paddingVertical: 50,
    justifyContent: 'flex-start',
    backgroundColor: 'white',
    alignItems: 'center'
  }
});
//# sourceMappingURL=AnimatedModal.js.map